@@ -2,7 +2,7 @@ package Nagios::Check::Email::Sender;
 use strict;
 use warnings;
 
-our $VERSION = '0.0';
+our $VERSION = '0.1';
 # ABSTRACT: nagios check for complete email sending
 
 =head1 SYNOPSIS 
@@ -17,13 +17,16 @@ just run
 
 when conf.yml can be 
 
-
     host: mailhost.example.com
     port: 25 
     to: monitor-recipient@example.com
     from: monitor@example.com 
 
-I really think that every parameter are self-explained. please email me if not.
+I really think that every parameter are self-explained. please email me if not. 
+
+You can also pass every param from argv (Thonas said it's a feature):
+
+    ./check_email_sender.pl host mailhost.example.com port 25 to monitor-recipient@example.com from monitor@example.com 
 
 =cut
 
